@@ -1,8 +1,8 @@
-use 5.006; use strict; no warnings;
+use 5.006; use strict; use warnings;
 
 package DBIx::Simple::Interpol;
 
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 
 use SQL::Interpol ();
 use DBIx::Simple ();
@@ -63,7 +63,7 @@ Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Aristotle Pagaltzis.
+This software is copyright (c) 2022 by Aristotle Pagaltzis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
